@@ -8,7 +8,7 @@ with sessions. (You can change this setting with the "db_notifications" setting
 in the "storage" setting.)
 '''
 
-from pycket.session import create_mixin, SessionManager, SessionMixin
+from pycket.session import create_mixin, SessionManager
 
 
 class NotificationManager(SessionManager):
@@ -34,4 +34,4 @@ class NotificationMixin(object):
         Returns a NotificationManager instance
         '''
 
-        return create_mixin(self, '__notification_manager', NotificationManager)
\ No newline at end of file
+        return create_mixin(self, '__notification_manager', NotificationManager)
